@@ -9,16 +9,20 @@
 
 import pandas as pd
 
-from . import Meteonet
 from climetlab.utils import download_and_cache
 
+from . import Meteonet
+
 
 class MeteonetGroundStations(Meteonet):
     """
     See https://github.com/meteofrance/meteonet
     """
 
-    def __init__(self, domain="NW", date="20160101"):
+    def __init__(self):
+        pass
+
+    def _load(self, domain="NW", date="20160101"):
 
         url = "{url}/ground_stations/{domain}_{date}.csv".format(
             url=self.URL, domain=domain, date=date
