@@ -8,16 +8,20 @@
 #
 
 
-from . import Meteonet
 from climetlab import load_source
 
+from . import Meteonet
+
 
 class MeteonetWeatherModels(Meteonet):
     """
     See https://github.com/meteofrance/meteonet
     """
 
-    def __init__(
+    def __init__(self):
+        pass
+
+    def _load(
         self, model="arome", variable="2m", domain="NW", date="20180501", time="0000"
     ):
 
