@@ -1,12 +1,9 @@
 import folium
 import folium.plugins
 from branca.element import MacroElement
-from jinja2 import Template
-import os
-from climetlab.core.ipython import HTML
 from folium.map import Layer
-import base64
-from climetlab.utils.bbox import BoundingBox
+from jinja2 import Template
+from climetlab.core.ipython import HTML
 
 
 class SVGOverlay(Layer):
@@ -56,15 +53,6 @@ class SVGOverlay(Layer):
         return self.bounds
 
 
-with open(os.path.join(os.path.dirname(__file__), "wms.j2")) as f:
-    direct_wms = f.read()
-
-
-class DirectWMS(folium.raster_layers.WmsTileLayer):
-    _name = "DirectWMS"
-    _template = Template(direct_wms)
-
-
 class NoScrollZoom(MacroElement):
     _name = "NoScrollZoom"
     _template = Template(
@@ -81,11 +69,7 @@ class NoScrollZoom(MacroElement):
 
 
 def make_map(path, bbox, **kwargs):
-    # Prefer `folium` to `ipyleafet` as it does not
-    # rely on ipywidgets, that are not always available
-    # from ipyleaflet import Map, WMSLayer, projections, FullScreenControl
 
-    # bbox = BoundingBox(north=90, west=-180, south=-90, east=180)
     center = (0, 0)
     zoom = 1
 
@@ -94,30 +78,25 @@ def make_map(path, bbox, **kwargs):
         zoom = 1 / max((bbox.north - bbox.south) / 180, (bbox.east - bbox.west) / 360)
         zoom = (2 * zoom + 88) / 27
 
-    m = folium.Map(zoom_start=zoom, location=center)  # , crs="Simple")
+    m = folium.Map(zoom_start=zoom, location=center)
 
     SVGOverlay(
         path=path,
         # bounds=[[85.051129, -180],[-85.051129, 180]],
         bounds=[[90, -180], [-90, 180]],
-        options=dict(opacity=0.6, autoZIndex=True),
+        # options=dict(opacity=0.6, autoZIndex=True),
     ).add_to(m)
 
-    # DirectWMS(
-    #     url=url, layers=["climetlab"], transparent=True, fmt="image/png", **kwargs
-    # ).add_to(m)
-
-    # https://github.com/python-visualization/folium/blob/master/examples/Plugins.ipynb
-    # https://deepnote.com/publish/9ad481b5-5756-4710-a839-2e129e0d9d94
-
     folium.plugins.Fullscreen(force_separate_button=True).add_to(m)
     NoScrollZoom().add_to(m)
 
     if bbox is not None:
         m.fit_bounds([[bbox.south, bbox.east], [bbox.north, bbox.west]])
 
-    return m
-    # with open(os.path.join(os.path.dirname(__file__), "wms.js")) as f:
-    #     wms_js = f.read()
+    html = m._repr_html_()
+    # For deepnote
+    html = html.replace("width: 100%;height: 100%", "width: 100%").replace(
+        "height: 100.0%;", "height: 609px;"
+    )
 
-    # return HTML("<script>{}</script>{}".format(wms_js, m._repr_html_()))
+    return HTML(html)
