@@ -7,9 +7,10 @@
 # nor does it submit to any jurisdiction.
 #
 
-from . import MultiSource, File
 from climetlab.utils.pattern import Pattern
 
+from . import File, MultiSource
+
 
 class FilePattern(MultiSource):
     def __init__(self, pattern, *args, **kwargs):
